@@ -201,8 +201,14 @@ class ApiResource(object):
                         error_json=error_json
                     )
 
+            try:
+                error_json = response.json()
+            except:
+                error_json = None
+
             raise UnexpectedResponseError('unexpected HTTP status code: '
-                                          '%d' % (response.status_code))
+                                          '%d' % (response.status_code),
+                                          error_json=error_json)
 
         # Verify the content MIME type.
         content_type = response.headers.get('Content-Type', '')
@@ -869,8 +875,8 @@ class Transaction(MappableResource,
             )
         except UnexpectedResponseError as exception:
             if exception.error_json and \
-                    exception.error_json.get('exception') == \
-                    'refund_amount_to_high':
+               exception.error_json.get('exception') == \
+               'refund_amount_to_high':
                 raise RefundedAmountTooHighError()
             raise
 
